Gramex
======

Gramex: Visual Analytics Platform.

Gramex is a component-based building blocks approach to DataApps.

Gramex is not free for commercial use! Please read the `LICENSE`_ file.
To discuss commercial use of Gramex, reach out to contact@gramener.com.

Gramex is offered under a non-commercial license for

- Educational & research institutions
- Students
- Individuals using for personal use, testing and demonstration

For usage instructions, see the `Gramex Guide`_.

.. _LICENSE: https://code.gramener.com/cto/gramex/blob/master/LICENSE.rst
.. _Gramex Guide: https://learn.gramener.com/guide/
